thulp-registry
Tool registry implementation for thulp.
This crate provides a registry for managing tool definitions and configurations, including loading from configuration files, caching, and discovery.
Structs
- Tool
Registry - Tool registry for managing and discovering tools.